Replace Thinkness with Thickness.

The FontMetricsFlags::kUnderlineThinknessIsValid_Flag has a typo in it.
Fortunately no user currently uses this enumeration value by name but
instead uses the getter so the name can be updated.

BUG=skia:6174

Change-Id: I810260d826482de1da8876cd9739d24b3bfb0f95
Reviewed-on: https://skia-review.googlesource.com/10050
Reviewed-by: Cary Clark <caryclark@google.com>
Commit-Queue: Ben Wagner <bungeman@google.com>
diff --git a/include/core/SkPaint.h b/include/core/SkPaint.h
index c8d4cc1..caa5491 100644
--- a/include/core/SkPaint.h
+++ b/include/core/SkPaint.h
@@ -707,7 +707,7 @@
             A set flag indicates that the metric may be trusted.
         */
         enum FontMetricsFlags {
-            kUnderlineThinknessIsValid_Flag = 1 << 0,
+            kUnderlineThicknessIsValid_Flag = 1 << 0,
             kUnderlinePositionIsValid_Flag = 1 << 1,
         };
 
@@ -733,21 +733,21 @@
          */
         SkScalar    fUnderlinePosition; //!< underline position, or 0 if cannot be determined
 
-        /**  If the fontmetrics has a valid underlinethickness, return true, and set the
+        /**  If the fontmetrics has a valid underline thickness, return true, and set the
                 thickness param to that value. If it doesn't return false and ignore the
                 thickness param.
         */
         bool hasUnderlineThickness(SkScalar* thickness) const {
-            if (SkToBool(fFlags & kUnderlineThinknessIsValid_Flag)) {
+            if (SkToBool(fFlags & kUnderlineThicknessIsValid_Flag)) {
                 *thickness = fUnderlineThickness;
                 return true;
             }
             return false;
         }
 
-        /**  If the fontmetrics has a valid underlineposition, return true, and set the
-                thickness param to that value. If it doesn't return false and ignore the
-                thickness param.
+        /**  If the fontmetrics has a valid underline position, return true, and set the
+                position param to that value. If it doesn't return false and ignore the
+                position param.
         */
         bool hasUnderlinePosition(SkScalar* position) const {
             if (SkToBool(fFlags & kUnderlinePositionIsValid_Flag)) {